@@ -844,7 +844,8 @@ class CommonFunctions
                 'ACRNACRNACRN' => 'acrn', // ACRN hypervisor
                 'TCGTCGTCGTCG' => 'qemu', // QEMU
                 'QNXQVMBSQG' => 'qnx', // QNX hypervisor
-                'VBoxVBoxVBox' => 'oracle' // Oracle VM VirtualBox
+                'VBoxVBoxVBox' => 'oracle', // Oracle VM VirtualBox
+                'SRESRESRESRE' => 'sre' // LMHS SRE hypervisor
             );
             $shortvendorid = trim(preg_replace('/[\s!\.]/', '', $vendor_data));
             if (($shortvendorid !== "") && isset($vidarray[$shortvendorid])) {
