@@ -171,8 +171,8 @@ class PSI_Error
             $error->addAttribute('Message', $arrLine['message']);
             $error->addAttribute('Function', $arrLine['command']);
         }
-        header("Cache-Control: no-cache, must-revalidate\n");
-        header("Content-Type: text/xml\n\n");
+        header('Cache-Control: no-cache, must-revalidate');
+        header('Content-Type: text/xml');
         echo $xml->getSimpleXmlElement()->asXML();
         exit();
     }
@@ -229,7 +229,9 @@ class PSI_Error
             if ($val == $arrTrace[count($arrTrace) - 1]) {
                 break;
             }
-            $strBacktrace .= str_replace(APP_ROOT, ".", $val['file']).' on line '.$val['line'];
+            if (isset($val['file'])) {
+                $strBacktrace .= str_replace(PSI_APP_ROOT, ".", $val['file']).' on line '.$val['line'];
+            }
             if ($strFunc) {
                 $strBacktrace .= ' in function '.$strFunc;
             }
@@ -238,6 +240,10 @@ class PSI_Error
             } else {
                 $strFunc = $val['function'].'(';
                 if (isset($val['args'][0])) {
+                    if (($val['function'] == 'executeProgram') && ($val['args'][0] == 'sshpass')
+                       && isset($val['args'][1]) && preg_match('/"([^"]+)"$/', $val['args'][1], $tmpout)) {
+                        $val['args'][1] = 'ssh: '. $tmpout[1];
+                    }
                     $strFunc .= ' ';
                     $strComma = '';
                     foreach ($val['args'] as $valArgs) {
