@@ -1,25 +1,13 @@
 <?php
 /**
- * speedfan sensor class
+ * speedfan sensor class, getting hardware information through SpeedFanGet
  *
  * PHP version 5
  *
  * @category  PHP
  * @package   PSI_Sensor
- * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
- * @copyright 2009 phpSysInfo
- * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
- * @version   SVN: $Id: class.speedfan.inc.php 661 2012-08-27 11:26:39Z namiltd $
- * @link      http://phpsysinfo.sourceforge.net
- */
- /**
- * getting hardware temperature information through snmpwalk
- *
- * @category  PHP
- * @package   PSI_Sensor
- * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
- * @author    William Johansson <radar@radhuset.org>
- * @copyright 2009 phpSysInfo
+ * @author    Mieczyslaw Nalewaj <namiltd@users.sourceforge.net>
+ * @copyright 2016 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License version 2, or (at your option) any later version
  * @version   Release: 3.0
  * @link      http://phpsysinfo.sourceforge.net
@@ -35,7 +23,7 @@ class SpeedFan extends Sensors
     public function __construct()
     {
         parent::__construct();
-        switch (defined('PSI_SENSOR_SPEEDFAN_ACCESS')?strtolower(PSI_SENSOR_SPEEDFAN_ACCESS):'command') {
+        if ((PSI_OS == 'WINNT') && !defined('PSI_EMU_HOSTNAME')) switch (defined('PSI_SENSOR_SPEEDFAN_ACCESS')?strtolower(PSI_SENSOR_SPEEDFAN_ACCESS):'command') {
         case 'command':
             if (CommonFunctions::executeProgram("SpeedFanGet.exe", "", $buffer, PSI_DEBUG) && (strlen($buffer) > 0)) {
                 if (preg_match("/^Temperatures:\s+(.+)$/m", $buffer, $out)) {
@@ -50,7 +38,7 @@ class SpeedFan extends Sensors
             }
             break;
         case 'data':
-            if (CommonFunctions::rfts(APP_ROOT.'/data/speedfan.txt', $buffer) && (strlen($buffer) > 0)) {
+            if (CommonFunctions::rftsdata('speedfan.tmp', $buffer) && (strlen($buffer) > 0)) {
                 if (preg_match("/^Temperatures:\s+(.+)$/m", $buffer, $out)) {
                     $this->_filecontent["temp"] = $out[1];
                 }
@@ -63,8 +51,7 @@ class SpeedFan extends Sensors
             }
             break;
         default:
-            $this->error->addConfigError('__construct()', 'PSI_SENSOR_SPEEDFAN_ACCESS');
-            break;
+            $this->error->addConfigError('__construct()', '[sensor_speedfan] ACCESS');
         }
     }
 
@@ -127,7 +114,7 @@ class SpeedFan extends Sensors
      *
      * @see PSI_Interface_Sensor::build()
      *
-     * @return Void
+     * @return void
      */
     public function build()
     {
