@@ -28,21 +28,21 @@ class Webpage extends Output implements PSI_Interface_Output
     /**
      * configured indexname
      *
-     * @var String
+     * @var string
      */
     private $_indexname;
 
     /**
      * configured language
      *
-     * @var String
+     * @var string
      */
     private $_language;
 
     /**
      * configured template
      *
-     * @var String
+     * @var string
      */
     private $_template;
 
@@ -56,7 +56,7 @@ class Webpage extends Output implements PSI_Interface_Output
     /**
      * configured bootstrap template
      *
-     * @var String
+     * @var string
      */
     private $_bootstrap_template;
 
@@ -108,15 +108,15 @@ class Webpage extends Output implements PSI_Interface_Output
      */
     private function _checkTemplateLanguage()
     {
-        if (!defined("PSI_DEFAULT_TEMPLATE") || (($this->_template = strtolower(trim(PSI_DEFAULT_TEMPLATE))) == "") || !file_exists(APP_ROOT.'/templates/'.$this->_template.".css")) {
+        if (!defined("PSI_DEFAULT_TEMPLATE") || (($this->_template = strtolower(trim(PSI_DEFAULT_TEMPLATE))) == "") || !file_exists(PSI_APP_ROOT.'/templates/'.$this->_template.".css")) {
             $this->_template = 'phpsysinfo';
         }
-        if (!defined("PSI_DEFAULT_BOOTSTRAP_TEMPLATE") || (($this->_bootstrap_template = strtolower(trim(PSI_DEFAULT_BOOTSTRAP_TEMPLATE))) == "") || !file_exists(APP_ROOT.'/templates/'.$this->_bootstrap_template."_bootstrap.css")) {
+        if (!defined("PSI_DEFAULT_BOOTSTRAP_TEMPLATE") || (($this->_bootstrap_template = strtolower(trim(PSI_DEFAULT_BOOTSTRAP_TEMPLATE))) == "") || !file_exists(PSI_APP_ROOT.'/templates/'.$this->_bootstrap_template."_bootstrap.css")) {
             $this->_bootstrap_template = 'phpsysinfo';
         }
         $this->_pick_template = !defined("PSI_SHOW_PICKLIST_TEMPLATE") || (PSI_SHOW_PICKLIST_TEMPLATE !== false);
 
-        if (!defined("PSI_DEFAULT_LANG") || (($this->_language = strtolower(trim(PSI_DEFAULT_LANG))) == "") || !file_exists(APP_ROOT.'/language/'.$this->_language.".xml")) {
+        if (!defined("PSI_DEFAULT_LANG") || (($this->_language = strtolower(trim(PSI_DEFAULT_LANG))) == "") || !file_exists(PSI_APP_ROOT.'/language/'.$this->_language.".xml")) {
             $this->_language = 'en';
         }
         $this->_pick_language = !defined("PSI_SHOW_PICKLIST_LANG") || (PSI_SHOW_PICKLIST_LANG !== false);
@@ -129,7 +129,7 @@ class Webpage extends Output implements PSI_Interface_Output
      */
     private function _getTemplateList()
     {
-        $dirlist = CommonFunctions::gdc(APP_ROOT.'/templates/');
+        $dirlist = CommonFunctions::gdc(PSI_APP_ROOT.'/templates/');
         sort($dirlist);
         foreach ($dirlist as $file) {
             $tpl_ext = substr($file, strlen($file) - 4);
@@ -151,7 +151,7 @@ class Webpage extends Output implements PSI_Interface_Output
      */
     private function _getLanguageList()
     {
-        $dirlist = CommonFunctions::gdc(APP_ROOT.'/language/');
+        $dirlist = CommonFunctions::gdc(PSI_APP_ROOT.'/language/');
         sort($dirlist);
         foreach ($dirlist as $file) {
             $lang_ext = strtolower(substr($file, strlen($file) - 4));
@@ -187,6 +187,9 @@ class Webpage extends Output implements PSI_Interface_Output
         $tpl->set("showMemoryInfosExpanded", defined('PSI_SHOW_MEMORY_INFOS_EXPANDED') ? (PSI_SHOW_MEMORY_INFOS_EXPANDED ? 'true' : 'false') : 'false');
         $tpl->set("showNetworkActiveSpeed", defined('PSI_SHOW_NETWORK_ACTIVE_SPEED') ? (PSI_SHOW_NETWORK_ACTIVE_SPEED ? ((strtolower(PSI_SHOW_NETWORK_ACTIVE_SPEED) === 'bps') ? 'bps' :'true') : 'false') : 'false');
         $tpl->set("showCPULoadCompact", defined('PSI_LOAD_BAR') ? ((strtolower(PSI_LOAD_BAR) === 'compact') ? 'true' :'false') : 'false');
+        $tpl->set("hideBootstrapLoader", defined('PSI_HIDE_BOOTSTRAP_LOADER') ? (PSI_HIDE_BOOTSTRAP_LOADER ? 'true' : 'false') : 'false');
+        $tpl->set("increaseWidth", defined('PSI_INCREASE_WIDTH') ? ((intval(PSI_INCREASE_WIDTH)>0) ? intval(PSI_INCREASE_WIDTH) : 0) : 0);
+        $tpl->set("hideTotals", defined('PSI_HIDE_TOTALS') ? (PSI_HIDE_TOTALS ? 'true' : 'false') : 'false');
         if (defined('PSI_BLOCKS')) {
             if (is_string(PSI_BLOCKS)) {
                 if (preg_match(ARRAY_EXP, PSI_BLOCKS)) {
