@@ -86,10 +86,11 @@ abstract class PSI_Plugin implements PSI_Interface_Plugin
      */
     private function _getconfig()
     {
-        if ((!defined('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_ACCESS')) &&
-             (!defined('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_FILE')) &&
-             (!defined('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_SHOW_SERIAL'))) {
-                $this->global_error->addError("phpsysinfo.ini", "Config for plugin ".$this->_plugin_name." not exist!");
+        if ((strtoupper($this->_plugin_name) !== 'DISKLOAD') &&
+           (!defined('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_ACCESS')) &&
+           (!defined('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_FILE')) &&
+           (!defined('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_SHOW_SERIAL'))) {
+            $this->global_error->addError("phpsysinfo.ini", "Config for plugin ".$this->_plugin_name." not exist!");
         }
     }
 
@@ -131,8 +132,10 @@ abstract class PSI_Plugin implements PSI_Interface_Plugin
         $dom->appendChild($root);
         $this->xml = new SimpleXMLExtended(simplexml_import_dom($dom), $enc);
         $plugname = strtoupper($this->_plugin_name);
-        if (((PSI_OS == 'WINNT') || (PSI_OS == 'Linux')) &&
-           defined('PSI_PLUGIN_'.$plugname.'_WMI_HOSTNAME') &&
+        if ((PSI_OS == 'Linux') && defined('PSI_PLUGIN_'.$plugname.'_SSH_HOSTNAME') &&
+           (!defined('PSI_SSH_HOSTNAME') || (PSI_SSH_HOSTNAME != constant('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_SSH_HOSTNAME')))) {
+            $this->xml->addAttribute('Hostname', constant('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_SSH_HOSTNAME'));
+        } elseif (((PSI_OS == 'WINNT') || (PSI_OS == 'Linux')) && defined('PSI_PLUGIN_'.$plugname.'_WMI_HOSTNAME') &&
            (!defined('PSI_WMI_HOSTNAME') || (PSI_WMI_HOSTNAME != constant('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_WMI_HOSTNAME')))) {
             $this->xml->addAttribute('Hostname', constant('PSI_PLUGIN_'.strtoupper($this->_plugin_name).'_WMI_HOSTNAME'));
         }
