@@ -281,16 +281,15 @@ class XML
 
         if (defined('PSI_SHOW_VIRTUALIZER_INFO') && PSI_SHOW_VIRTUALIZER_INFO) {
             $virt = $this->_sys->getVirtualizer();
-            $first = true;
             $virtstring = "";
             foreach ($virt as $virtkey=>$virtvalue) if ($virtvalue) {
-                if ($first) {
-                    $first = false;
-                } else {
+                if ($virtstring !== "") {
                     $virtstring .= ", ";
                 }
                 if ($virtkey === 'microsoft') {
-                    $virtstring .= 'hyper-v';
+                    if (!isset($virt["wsl"]) || !$virt["wsl"]) {
+                        $virtstring .= 'hyper-v';
+                    }
                 } elseif ($virtkey === 'kvm') {
                     $virtstring .= 'qemu-kvm';
                 } elseif ($virtkey === 'oracle') {
@@ -661,124 +660,149 @@ class XML
     {
         $mbinfo = $this->_xml->addChild('MBInfo');
         $temp = $fan = $volt = $power = $current = $other = null;
+        $hideSensors = array();
 
         if (sizeof(unserialize(PSI_MBINFO))>0) {
+            if (defined('PSI_HIDE_SENSORS') && is_string(PSI_HIDE_SENSORS)) {
+                 if (preg_match(ARRAY_EXP, PSI_HIDE_SENSORS)) {
+                    $hideSensors = eval(PSI_HIDE_SENSORS);
+                } else {
+                    $hideSensors = array(PSI_HIDE_SENSORS);
+                }
+            }
             foreach (unserialize(PSI_MBINFO) as $mbinfoclass) {
                 $mbinfo_data = new $mbinfoclass();
                 $mbinfo_detail = $mbinfo_data->getMBInfo();
-
-                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='temperature') foreach ($mbinfo_detail->getMbTemp() as $dev) {
-                    if ($temp == null) {
-                        $temp = $mbinfo->addChild('Temperature');
-                    }
-                    $item = $temp->addChild('Item');
-                    $item->addAttribute('Label', $dev->getName());
-                    $item->addAttribute('Value', $dev->getValue());
-                    $alarm = false;
-                    if ($dev->getMax() !== null) {
-                        $item->addAttribute('Max', $dev->getMax());
-                        $alarm = true;
-                    }
-                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
-                        $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
-                    }
-                }
-
-                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='fans') foreach ($mbinfo_detail->getMbFan() as $dev) {
-                    if ($fan == null) {
-                        $fan = $mbinfo->addChild('Fans');
-                    }
-                    $item = $fan->addChild('Item');
-                    $item->addAttribute('Label', $dev->getName());
-                    $item->addAttribute('Value', $dev->getValue());
-                    $alarm = false;
-                    if ($dev->getMin() !== null) {
-                        $item->addAttribute('Min', $dev->getMin());
-                        $alarm = true;
-                    }
-                    if ($dev->getUnit() !== "") {
-                        $item->addAttribute('Unit', $dev->getUnit());
-                    }
-                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
-                        $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
-                    }
-                }
-
-                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='voltage') foreach ($mbinfo_detail->getMbVolt() as $dev) {
-                    if ($volt == null) {
-                        $volt = $mbinfo->addChild('Voltage');
-                    }
-                    $item = $volt->addChild('Item');
-                    $item->addAttribute('Label', $dev->getName());
-                    $item->addAttribute('Value', $dev->getValue());
-                    $alarm = false;
-                    if (($dev->getMin() === null) || ($dev->getMin() != 0) || ($dev->getMax() === null) || ($dev->getMax() != 0)) {
-                        if ($dev->getMin() !== null) {
-                            $item->addAttribute('Min', $dev->getMin());
-                            $alarm = true;
+                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='temperature' || $this->_sysinfo->getBlockName()==='mbinfo') foreach ($mbinfo_detail->getMbTemp() as $dev) {
+                    $mbinfo_name = $dev->getName();
+                    if (!in_array($mbinfo_name, $hideSensors, true)) {
+                        if ($temp == null) {
+                            $temp = $mbinfo->addChild('Temperature');
                         }
+                        $item = $temp->addChild('Item');
+                        $item->addAttribute('Label', $mbinfo_name);
+                        $item->addAttribute('Value', $dev->getValue());
+                        $alarm = false;
                         if ($dev->getMax() !== null) {
                             $item->addAttribute('Max', $dev->getMax());
                             $alarm = true;
                         }
-                    }
-                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
-                        $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
+                        if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
+                            $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
+                        }
                     }
                 }
 
-                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='power') foreach ($mbinfo_detail->getMbPower() as $dev) {
-                    if ($power == null) {
-                        $power = $mbinfo->addChild('Power');
-                    }
-                    $item = $power->addChild('Item');
-                    $item->addAttribute('Label', $dev->getName());
-                    $item->addAttribute('Value', $dev->getValue());
-                    $alarm = false;
-                    if ($dev->getMax() !== null) {
-                        $item->addAttribute('Max', $dev->getMax());
-                        $alarm = true;
-                    }
-                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
-                        $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
-                    }
-                }
-
-                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='current') foreach ($mbinfo_detail->getMbCurrent() as $dev) {
-                    if ($current == null) {
-                        $current = $mbinfo->addChild('Current');
-                    }
-                    $item = $current->addChild('Item');
-                    $item->addAttribute('Label', $dev->getName());
-                    $item->addAttribute('Value', $dev->getValue());
-                    $alarm = false;
-                    if (($dev->getMin() === null) || ($dev->getMin() != 0) || ($dev->getMax() === null) || ($dev->getMax() != 0)) {
+                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='fans' || $this->_sysinfo->getBlockName()==='mbinfo') foreach ($mbinfo_detail->getMbFan() as $dev) {
+                    $mbinfo_name = $dev->getName();
+                    if (!in_array($mbinfo_name, $hideSensors, true)) {
+                        if ($fan == null) {
+                            $fan = $mbinfo->addChild('Fans');
+                        }
+                        $item = $fan->addChild('Item');
+                        $item->addAttribute('Label', $mbinfo_name);
+                        $item->addAttribute('Value', $dev->getValue());
+                        $alarm = false;
                         if ($dev->getMin() !== null) {
                             $item->addAttribute('Min', $dev->getMin());
                             $alarm = true;
                         }
+                        if ($dev->getUnit() !== "") {
+                            $item->addAttribute('Unit', $dev->getUnit());
+                        }
+                        if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
+                            $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
+                        }
+                    }
+                }
+
+                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='voltage' || $this->_sysinfo->getBlockName()==='mbinfo') foreach ($mbinfo_detail->getMbVolt() as $dev) {
+                    $mbinfo_name = $dev->getName();
+                    if (!in_array($mbinfo_name, $hideSensors, true)) {
+                        if ($volt == null) {
+                            $volt = $mbinfo->addChild('Voltage');
+                        }
+                        $item = $volt->addChild('Item');
+                        $item->addAttribute('Label', $mbinfo_name);
+                        $item->addAttribute('Value', $dev->getValue());
+                        $alarm = false;
+                        if (($dev->getMin() === null) || ($dev->getMin() != 0) || ($dev->getMax() === null) || ($dev->getMax() != 0)) {
+                            if ($dev->getMin() !== null) {
+                                $item->addAttribute('Min', $dev->getMin());
+                                $alarm = true;
+                            }
+                            if ($dev->getMax() !== null) {
+                                $item->addAttribute('Max', $dev->getMax());
+                                $alarm = true;
+                            }
+                        }
+                        if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
+                            $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
+                        }
+                    }
+                }
+
+                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='power' || $this->_sysinfo->getBlockName()==='mbinfo') foreach ($mbinfo_detail->getMbPower() as $dev) {
+                    $mbinfo_name = $dev->getName();
+                    if (!in_array($mbinfo_name, $hideSensors, true)) {
+                        if ($power == null) {
+                            $power = $mbinfo->addChild('Power');
+                        }
+                        $item = $power->addChild('Item');
+                        $item->addAttribute('Label', $mbinfo_name);
+                        $item->addAttribute('Value', $dev->getValue());
+                        $alarm = false;
                         if ($dev->getMax() !== null) {
                             $item->addAttribute('Max', $dev->getMax());
                             $alarm = true;
                         }
-                    }
-                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
-                        $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
+                        if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
+                            $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
+                        }
                     }
                 }
 
-                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='other') foreach ($mbinfo_detail->getMbOther() as $dev) {
-                    if ($other == null) {
-                        $other = $mbinfo->addChild('Other');
+                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='current' || $this->_sysinfo->getBlockName()==='mbinfo') foreach ($mbinfo_detail->getMbCurrent() as $dev) {
+                    $mbinfo_name = $dev->getName();
+                    if (!in_array($mbinfo_name, $hideSensors, true)) {
+                        if ($current == null) {
+                            $current = $mbinfo->addChild('Current');
+                        }
+                        $item = $current->addChild('Item');
+                        $item->addAttribute('Label', $mbinfo_name);
+                        $item->addAttribute('Value', $dev->getValue());
+                        $alarm = false;
+                        if (($dev->getMin() === null) || ($dev->getMin() != 0) || ($dev->getMax() === null) || ($dev->getMax() != 0)) {
+                            if ($dev->getMin() !== null) {
+                                $item->addAttribute('Min', $dev->getMin());
+                                $alarm = true;
+                            }
+                            if ($dev->getMax() !== null) {
+                                $item->addAttribute('Max', $dev->getMax());
+                                $alarm = true;
+                            }
+                        }
+                        if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && ($dev->getEvent() !== "") && (((strtolower($dev->getEvent())) !== "alarm") || $alarm || ($dev->getValue() == 0))) {
+                            $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
+                        }
                     }
-                    $item = $other->addChild('Item');
-                    $item->addAttribute('Label', $dev->getName());
-                    $item->addAttribute('Value', $dev->getValue());
-                    if ($dev->getUnit() !== "") {
-                        $item->addAttribute('Unit', $dev->getUnit());
-                    }
-                    if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
-                        $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
+                }
+
+                if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='other' || $this->_sysinfo->getBlockName()==='mbinfo') foreach ($mbinfo_detail->getMbOther() as $dev) {
+                    $mbinfo_name = $dev->getName();
+                    if (!in_array($mbinfo_name, $hideSensors, true)) {
+                        if ($other == null) {
+                            $other = $mbinfo->addChild('Other');
+                        }
+                        $item = $other->addChild('Item');
+                        $item->addAttribute('Label', $mbinfo_name);
+                        $item->addAttribute('Value', $dev->getValue());
+                        if ($dev->getUnit() !== "") {
+                            $item->addAttribute('Unit', $dev->getUnit());
+                        }
+                        if (defined('PSI_SENSOR_EVENTS') && PSI_SENSOR_EVENTS && $dev->getEvent() !== "") {
+                            $item->addAttribute('Event', ucfirst(strtolower($dev->getEvent())));
+                        }
                     }
                 }
             }
@@ -897,7 +921,7 @@ class XML
             if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='hardware') $this->_buildHardware();
             if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='memory') $this->_buildMemory();
             if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='filesystem') $this->_buildFilesystems();
-            if (!$this->_sysinfo->getBlockName() || in_array($this->_sysinfo->getBlockName(), array('voltage','current','temperature','fans','power','other'))) $this->_buildMbinfo();
+            if (!$this->_sysinfo->getBlockName() || in_array($this->_sysinfo->getBlockName(), array('mbinfo','voltage','current','temperature','fans','power','other'))) $this->_buildMbinfo();
             if (!$this->_sysinfo->getBlockName() || $this->_sysinfo->getBlockName()==='ups') $this->_buildUpsinfo();
         }
         if (!$this->_sysinfo->getBlockName()) $this->_buildPlugins();
