@@ -1,15 +1,20 @@
 function renderPlugin_psstatus(data) {
 
     var directives = {
-        Status: {
+        Status1: {
             text: function () {
-                return (this['Status'] === "1") ? "ON" : "OFF";
+                return (this.Status === "1") ? "ON" : "";
+            }
+        },
+        Status0: {
+            text: function () {
+                return (this.Status === "1") ? "" : "OFF";
             }
         }
     };
 
-    if (data['Plugins']['Plugin_PSStatus'] !== undefined) {
-        var psitems = items(data['Plugins']['Plugin_PSStatus']['Process']);
+    if (data.Plugins.Plugin_PSStatus !== undefined) {
+        var psitems = items(data.Plugins.Plugin_PSStatus.Process);
         if (psitems.length > 0) {
             var ps_memory = [];
             ps_memory.push_attrs(psitems);
