@@ -1,5 +1,5 @@
 <?php
-header("Content-Type: text/plain");
+header('Content-Type: text/plain');
 $filemaskarray=array("/etc/*-release",
                      "/etc/*_release",
                      "/etc/*-version",
@@ -35,11 +35,14 @@ if (is_resource($fp)) {
 }
 
 foreach ($filemaskarray as $filemask) {
-    foreach (glob($filemask) as $filename) {
-        echo "----------".$filename."----------\n";
-        echo $contents=file_get_contents($filename);
-        if ((strlen($contents)>0)&&(substr($contents, -1)!="\n")) {
-            echo "\n";
+    $filenames = glob($filemask);
+    if (is_array($filenames)) foreach ($filenames as $filename) {
+        if (!is_dir($filename)) {
+            echo "----------".$filename."----------\n";
+            echo $contents=file_get_contents($filename);
+            if ((strlen($contents)>0)&&(substr($contents, -1)!="\n")) {
+                echo "\n";
+            }
         }
     }
 }
